"""
This module contains tow process template method and templates itself.

"""

import jinja2
import os


def process(template_path, template_name, result_file_path, context):
    """
    Process template
    """
    loader = jinja2.FileSystemLoader(template_path)
    jinja_env = jinja2.Environment(loader=loader)
    template = jinja_env.get_template(template_name)
    result = template.render(context)

    with open(result_file_path, "w+") as f:
        f.write(result)


def process_template(template_name, result_file_path, context):
    """
    Process template form templates folder
    """
    template_path = os.path.dirname(os.path.abspath(__file__))
    process(template_path, template_name, result_file_path, context)



"""
TODO: add comments
"""
import imp
import sys
import os


def load_module(env, module_path, name):
    """ This method load module file """
    module_file = os.path.join(module_path, "%s.py" % name)
    mod = None
    if os.path.exists(module_file):
        mod = imp.new_module(name)
        mod.__dict__.update({"env": env})
        sys.modules[name] = mod
        mod = imp.load_source(name, module_file)
    return mod



#!/usr/bin/env python

from __future__ import with_statement
from setuptools import setup, find_packages

long_description = """Tow provides a workflow for building docker images
                        with dynamics configuration files using templates.
                        The main concept is processing all configuration
                        templates outside of container and then build
                        image using pre-processed files."""


setup(
    name='tow',
    version='1.0.0-alpha-1',
    description='Tow is tool for automatization docker configuration managment workflow',
    long_description=long_description,
    author='Aleksei Kornev, Nikolay Yurin',
    author_email='aleksei.kornev@gmail.com, ',
    url='https://github.com/alekseiko/tow',
    packages=find_packages(),
    test_suite='nose.collector',
    tests_require=['nose'],
    install_requires=['jinja2'],
    package_data={
        '': ['*.tmpl'],
    },
    entry_points={
        'console_scripts': [
            'tow = tow.main:main',
        ]
    },
    classifiers=[
        'Environment :: Console',
        'Intended Audience :: Developers',
        'Intended Audience :: System Administrators',
        'Operating System :: Unix',
        'Operating System :: POSIX',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.7',
        'Topic :: Software Development',
        'Topic :: Software Development :: Build Tools',
        'Topic :: System :: Clustering',
        'Topic :: System :: Software Distribution',
        'Topic :: System :: Systems Administration',
    ],

)
